@@ -1,6 +1,6 @@
 package Subclass::Of;
 
-use v5.008;
+use 5.008;
 use strict;
 use warnings;
 no strict qw(refs);
@@ -8,12 +8,12 @@ no warnings qw(redefine prototype);
 
 BEGIN {
 	$Subclass::Of::AUTHORITY = 'cpan:TOBYINK';
-	$Subclass::Of::VERSION   = '0.000_03';
+	$Subclass::Of::VERSION   = '0.000_04';
 }
 
 use B qw(perlstring);
 use Carp qw(carp croak);
-use Module::Runtime qw(use_package_optimistically);
+use Module::Runtime qw(use_package_optimistically module_notional_filename);
 use List::MoreUtils qw(all);
 use Scalar::Util qw(refaddr);
 use Sub::Name qw(subname);
@@ -142,7 +142,10 @@ sub _parse_opts
 		$me->$method($parent, $child, $opts);
 		$me->_apply_methods($child, $opts);
 		$me->_apply_roles($child, $opts);
-
+		
+		my $i; $i++ while caller($i) eq __PACKAGE__;
+		$INC{module_notional_filename($child)} = (caller($i))[1];
+		
 		return $child;
 	}
 }
@@ -313,29 +316,29 @@ Subclass::Of - import a magic subclass
 
 Create a subclass overriding a method:
 
-	use Subclass::Of "LWP::UserAgent",
-		-as      => "ImpatientUA",
-		-methods => [
-			sub new {
-				my $self = ::SUPER();
-				$self->timeout(15);
-				$self->max_redirect(3);
-				return $self;
-			}
-		];
-	
-	my $ua = ImpatientUA->new;
+   use Subclass::Of "LWP::UserAgent",
+      -as      => "ImpatientUA",
+      -methods => [
+         sub new {
+            my $self = ::SUPER();
+            $self->timeout(15);
+            $self->max_redirect(3);
+            return $self;
+         }
+      ];
+   
+   my $ua = ImpatientUA->new;
 
 Create a subclass at runtime, adding roles:
 
-	use Subclass::Of;
-	
-	my $subclass = subclass_of(
-		"My::Class",
-		-with => [qw/ My::Role Your::Role His::Role Her::Role /],
-	);
-	
-	my $object = $subclass->new;
+   use Subclass::Of;
+   
+   my $subclass = subclass_of(
+      "My::Class",
+      -with => [qw/ My::Role Your::Role His::Role Her::Role /],
+   );
+   
+   my $object = $subclass->new;
 
 =head1 DESCRIPTION
 
@@ -348,7 +351,7 @@ subclass.
 
 To create a subclass at compile-time, use the following syntax:
 
-	use SubClass::Of $base_class, %options;
+   use SubClass::Of $base_class, %options;
 
 The following options are supported:
 
@@ -382,11 +385,11 @@ will think one up of its own.
 Subclass::Of will export a lexically scoped alias for the package name. By
 lexically scoped I mean:
 
-	{
-		use Subclass::Of "LWP::UserAgent", -as => "MyUA";
-		# "MyUA" is available here ...
-	}
-	# ... but not here
+   {
+      use Subclass::Of "LWP::UserAgent", -as => "MyUA";
+      # "MyUA" is available here ...
+   }
+   # ... but not here
 
 By "alias", I mean a constant that returns the subclass' package name as
 a string. (See L<aliased>.)
@@ -404,9 +407,9 @@ will be used. If you don't want an alias, try C<< -as => [] >>.
 
 To create a subclass at compile-time, use the following syntax:
 
-	use Subclass::Of;
-	
-	my $subclass = subclass_of($base_class, %options);
+   use Subclass::Of;
+   
+   my $subclass = subclass_of($base_class, %options);
 
 Note that the C<subclass_of> function is only exported if
 C<< use Subclass::Of >> is called with no import list.
@@ -425,8 +428,8 @@ C<< -as >> is ignored.
 If you need to provide a wrapper for Subclass::Of, and thus install scoped
 aliases into other packages, use the C<< install >> method:
 
-	require Subclass::Of;
-	Subclass::Of->install($base, -into => $target, %options);
+   require Subclass::Of;
+   Subclass::Of->install($base, -into => $target, %options);
 
 =begin trustme
 
